#[repr(C)]pub struct RSensorDescriptor {
pub id: RSensorId,
pub display_name: String,
pub unit: RUnit,
pub kind: RSensorKind,
pub category: RCategory,
pub native_rate_hz: f32,
pub min: Option<f64>,
pub max: Option<f64>,
pub device_id: Option<String>,
pub device_key: Option<String>,
pub tags: Vec<String>,
}Fields
id: RSensorIddisplay_name: Stringunit: RUnitkind: RSensorKindcategory: RCategorynative_rate_hz: f32min: Option<f64>max: Option<f64>device_id: Option<String>device_key: Option<String>ABI v4: optional hardware-device key (raw string form). Validated
by the host via HardwareDeviceKey::try_new in host_init.
NEW: sensor tags for filtering and grouping in the UI.
Implementations
Sourceimpl RSensorDescriptorwhere
Struct<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<RSensorId, String>, RUnit>, RSensorKind>, RCategory>, f32>, Option<f64>>, Option<f64>>, Option<String>>, Option<String>>, Vec<String>>>: IStable,
Vec<String>: IStable,
Option<String>: IStable,
Option<f64>: IStable,
f32: IStable,
RCategory: IStable,
RSensorKind: IStable,
RUnit: IStable,
String: IStable,
RSensorId: IStable,
impl RSensorDescriptorwhere
Struct<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<FieldPair<RSensorId, String>, RUnit>, RSensorKind>, RCategory>, f32>, Option<f64>>, Option<f64>>, Option<String>>, Option<String>>, Vec<String>>>: IStable,
Vec<String>: IStable,
Option<String>: IStable,
Option<f64>: IStable,
f32: IStable,
RCategory: IStable,
RSensorKind: IStable,
RUnit: IStable,
String: IStable,
RSensorId: IStable,
Sourcepub const fn has_optimal_layout() -> bool
pub const fn has_optimal_layout() -> bool
Returns true if the layout for RSensorDescriptor is smaller or equal to that Rust would have generated for it.